"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  flush: () => flush,
  get: () => get,
  getAll: () => getAll,
  getPrefix: () => getPrefix,
  getPrefixedKey: () => getPrefixedKey,
  hasPrefix: () => hasPrefix,
  keys: () => keys,
  rm: () => rm,
  sadd: () => sadd,
  set: () => set,
  setPrefix: () => setPrefix,
  sismember: () => sismember,
  smembers: () => smembers,
  srem: () => srem
});
module.exports = __toCommonJS(src_exports);

// src/prefix.ts
var PREFIX = "";
function setPrefix(prefix) {
  PREFIX = prefix;
  return PREFIX;
}
function getPrefixedKey(key, options) {
  if ((options == null ? void 0 : options.noPrefix) === true) {
    return key;
  } else {
    return `${PREFIX}${key}`;
  }
}
function hasPrefix() {
  return PREFIX.length > 0;
}
function getPrefix() {
  return PREFIX;
}
var prefix_default = getPrefix;

// src/set.ts
function set(key, value, options) {
  var query_key = getPrefixedKey(key, options);
  try {
    localStorage.setItem(query_key, JSON.stringify({ data: value }));
  } catch (e) {
    if (console) {
      console.warn(
        `Lockr didn't successfully save the '{"${key}": "${value}"}' pair, because the localStorage is full.`
      );
    }
  }
}

// src/smembers.ts
function smembers(key, options) {
  const queryKey = getPrefixedKey(key, options);
  let value;
  const localValue = localStorage.getItem(queryKey);
  if (localValue !== null) {
    value = JSON.parse(localValue);
  } else {
    value = null;
  }
  return value && value.data ? value.data : [];
}

// src/sadd.ts
function sadd(key, value, options) {
  const queryKey = getPrefixedKey(key, options);
  let json;
  var values = smembers(key);
  if (values.indexOf(value) > -1) {
    return false;
  }
  try {
    values.push(value);
    json = JSON.stringify({ data: values });
    localStorage.setItem(queryKey, json);
  } catch (e) {
    console.log(e);
    if (console)
      console.warn(
        "Lockr didn't successfully add the " + value + " to " + key + " set, because the localStorage is full."
      );
  }
  return true;
}

// src/rm.ts
function rm(key, options) {
  const queryKey = getPrefixedKey(key, options);
  return localStorage.removeItem(queryKey);
}

// src/get.ts
function get(key, missing, options) {
  const queryKey = getPrefixedKey(key, options);
  let value;
  const localValue = localStorage.getItem(queryKey);
  try {
    if (localValue !== null) {
      value = JSON.parse(localValue);
    }
  } catch (e) {
    if (localStorage[queryKey]) {
      value = { data: localStorage.getItem(queryKey) };
    } else {
      value = null;
    }
  }
  if (!value) {
    return missing;
  } else if (typeof value === "object" && typeof value.data !== "undefined") {
    return value.data;
  }
}

// src/keys.ts
function keys() {
  const prefix = prefix_default();
  const keys2 = [];
  const allKeys = Object.keys(localStorage);
  if (!hasPrefix()) {
    return allKeys;
  }
  allKeys.forEach(function(key) {
    if (key.indexOf(prefix) !== -1) {
      keys2.push(key.replace(prefix, ""));
    }
  });
  return keys2;
}

// src/getAll.ts
function getAll(includeKeys) {
  const keys2 = keys();
  if (includeKeys) {
    return keys2.reduce(function(accum, key) {
      const tempObj = {};
      tempObj[key] = get(key);
      accum.push(tempObj);
      return accum;
    }, []);
  }
  return keys2.map(function(key) {
    return get(key);
  });
}

// src/flush.ts
function flush() {
  if (hasPrefix()) {
    keys().forEach((key) => {
      localStorage.removeItem(getPrefixedKey(key));
    });
  } else {
    localStorage.clear();
  }
}

// src/sismember.ts
function sismember(key, value) {
  return smembers(key).indexOf(value) > -1;
}

// src/srem.ts
function srem(key, value, options) {
  const queryKey = getPrefixedKey(key, options);
  const values = smembers(key, value);
  const index = values.indexOf(value);
  if (index > -1) {
    values.splice(index, 1);
  }
  const json = JSON.stringify({ data: values });
  try {
    localStorage.setItem(queryKey, json);
  } catch (e) {
    if (console)
      console.warn(
        "Lockr couldn't remove the " + value + " from the set " + key
      );
  }
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  flush,
  get,
  getAll,
  getPrefix,
  getPrefixedKey,
  hasPrefix,
  keys,
  rm,
  sadd,
  set,
  setPrefix,
  sismember,
  smembers,
  srem
});
